# beanhub-inbox [![CircleCI](https://dl.circleci.com/status-badge/img/gh/LaunchPlatform/beanhub-inbox/tree/master.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/LaunchPlatform/beanhub-inbox/tree/master)

Email processing engine for archiving and extracting financial data with LLM.
This is a Python library for the email processing engine.
For the end-users, you may want to look into our command line tool [beanhub-cli](https://beanhub-cli-docs.beanhub.io/) that has beanhub-inbox integrated.
Please note that this project is more or less in the beta stage, and it's subject to rapid changes.

## Demo

<p align="center">
  <video src="https://github.com/user-attachments/assets/eb496dab-cd95-4aca-8a29-89ff9d52570d" autoplay muted>
</p>

# Sponsor

<p align="center">
  <a href="https://beanhub.io"><img src="https://github.com/LaunchPlatform/beanhub-cli/raw/master/assets/beanhub.svg?raw=true" alt="BeanHub logo" /></a>
</p>

A modern accounting book service based on the most popular open source version control system [Git](https://git-scm.com/) and text-based double entry accounting book software [Beancount](https://beancount.github.io/docs/index.html).
